==> paycenter-client-3.4.23-20230720.091828-2-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/shenzhenumsunionpay/UnionPayUmsRefundResponseData.java <==
package cn.com.duiba.paycenter.dto.payment.charge.shenzhenumsunionpay;

import java.util.List;

/**
 * @author UnionPayUmsRefundResponseData
 * @Description
 * @date 2023/7/19 14:56
 */
public class UnionPayUmsRefundResponseData {

    /**
     * 平台错误码
     * 0000：正常
     * 1000：认证失败
     * 1001：授权失败
     * 9001：参数校验失败
     * 9999：系统错误
     */
    private String errCode;

    /**
     * 平台错误信息
     * 0000：正常
     * 1000：认证失败
     * 1001：授权失败
     * 9001：参数校验失败
     * 9999：系统错误
     */
    private String errMsg;

    /**
     * 消息ID，原样返回
     */
    private String msgId;

    /**
     * 报文应答时间 格式yyyy-MM-dd HH:mm:ss
     */
    private String responseTimeStamp;

    /**
     * 请求系统预留字段
     */
    private String srcReserve;

    /**
     * 商户号，原样返回
     */
    private String mid;

    /**
     * 终端号，原样返回
     */
    private String tid;

    /**
     * 商户订单号
     */
    private String merOrderId;

    /**
     * 商户名称
     */
    private String merName;

    /**
     * 平台流水号
     */
    private String seqId;

    /**
     * 交易状态
     */
    private String status;

    /**
     * 支付渠道商户号
     */
    private String targetMid;

    /**
     * 目标平台单号 退货交易时不返回
     */
    private String targetOrderId;

    /**
     * 目标平台状态
     */
    private String targetStatus;

    /**
     * 目标平台代码
     */
    private String targetSys;

    /**
     * 支付总金额
     */
    private Long totalAmount;

    /**
     * 总退款金额
     */
    private String refundAmount;

    /**
     * 退款渠道列表
     */
    private String refundFunds;

    /**
     * 退款渠道描述
     */
    private String refundFundsDesc;

    /**
     * 实付部分退款金额
     */
    private Long refundInvoiceAmount;

    /**
     * 退货订单号
     */
    private String refundOrderId;

    /**
     * 目标系统退货订单号
     */
    private String refundTargetOrderId;

    /**
     * 营销联盟优惠金额 仅享受联盟优惠的订单，查询返回
     */
    private Long yxlmAmount;

    /**
     * 退款状态 详见取值说明
     */
    private String refundStatus;

    /**
     * 商户出资优惠金额 目前支持微信返回，其他渠道产品规划中
     */
    private Long refundMerchantContribute;

    /**
     * 其他出资优惠金额 目前支持微信返回，其他渠道产品规划中
     */
    private Long refundOtherContribute;


    public String getErrCode() {
        return errCode;
    }

    public void setErrCode(String errCode) {
        this.errCode = errCode;
    }

    public String getErrMsg() {
        return errMsg;
    }

    public void setErrMsg(String errMsg) {
        this.errMsg = errMsg;
    }

    public String getMsgId() {
        return msgId;
    }

    public void setMsgId(String msgId) {
        this.msgId = msgId;
    }

    public String getResponseTimeStamp() {
        return responseTimeStamp;
    }

    public void setResponseTimeStamp(String responseTimeStamp) {
        this.responseTimeStamp = responseTimeStamp;
    }

    public String getSrcReserve() {
        return srcReserve;
    }

    public void setSrcReserve(String srcReserve) {
        this.srcReserve = srcReserve;
    }

    public String getMid() {
        return mid;
    }

    public void setMid(String mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getMerOrderId() {
        return merOrderId;
    }

    public void setMerOrderId(String merOrderId) {
        this.merOrderId = merOrderId;
    }

    public String getMerName() {
        return merName;
    }

    public void setMerName(String merName) {
        this.merName = merName;
    }

    public String getSeqId() {
        return seqId;
    }

    public void setSeqId(String seqId) {
        this.seqId = seqId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getTargetMid() {
        return targetMid;
    }

    public void setTargetMid(String targetMid) {
        this.targetMid = targetMid;
    }

    public String getTargetOrderId() {
        return targetOrderId;
    }

    public void setTargetOrderId(String targetOrderId) {
        this.targetOrderId = targetOrderId;
    }

    public String getTargetStatus() {
        return targetStatus;
    }

    public void setTargetStatus(String targetStatus) {
        this.targetStatus = targetStatus;
    }

    public String getTargetSys() {
        return targetSys;
    }

    public void setTargetSys(String targetSys) {
        this.targetSys = targetSys;
    }

    public Long getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(Long totalAmount) {
        this.totalAmount = totalAmount;
    }

    public String getRefundAmount() {
        return refundAmount;
    }

    public void setRefundAmount(String refundAmount) {
        this.refundAmount = refundAmount;
    }

    public String getRefundFunds() {
        return refundFunds;
    }

    public void setRefundFunds(String refundFunds) {
        this.refundFunds = refundFunds;
    }

    public String getRefundFundsDesc() {
        return refundFundsDesc;
    }

    public void setRefundFundsDesc(String refundFundsDesc) {
        this.refundFundsDesc = refundFundsDesc;
    }

    public Long getRefundInvoiceAmount() {
        return refundInvoiceAmount;
    }

    public void setRefundInvoiceAmount(Long refundInvoiceAmount) {
        this.refundInvoiceAmount = refundInvoiceAmount;
    }

    public String getRefundOrderId() {
        return refundOrderId;
    }

    public void setRefundOrderId(String refundOrderId) {
        this.refundOrderId = refundOrderId;
    }

    public String getRefundTargetOrderId() {
        return refundTargetOrderId;
    }

    public void setRefundTargetOrderId(String refundTargetOrderId) {
        this.refundTargetOrderId = refundTargetOrderId;
    }

    public Long getYxlmAmount() {
        return yxlmAmount;
    }

    public void setYxlmAmount(Long yxlmAmount) {
        this.yxlmAmount = yxlmAmount;
    }

    public String getRefundStatus() {
        return refundStatus;
    }

    public void setRefundStatus(String refundStatus) {
        this.refundStatus = refundStatus;
    }

    public Long getRefundMerchantContribute() {
        return refundMerchantContribute;
    }

    public void setRefundMerchantContribute(Long refundMerchantContribute) {
        this.refundMerchantContribute = refundMerchantContribute;
    }

    public Long getRefundOtherContribute() {
        return refundOtherContribute;
    }

    public void setRefundOtherContribute(Long refundOtherContribute) {
        this.refundOtherContribute = refundOtherContribute;
    }
}

==> paycenter-client-3.5.35-20250915.094345-1-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/shenzhenumsunionpay/UnionPayUmsRefundResponseData.java <==
package cn.com.duiba.paycenter.dto.payment.charge.shenzhenumsunionpay;

import java.io.Serializable;
import java.util.List;

/**
 * @author UnionPayUmsRefundResponseData
 * @Description
 * @date 2023/7/19 14:56
 */
public class UnionPayUmsRefundResponseData implements Serializable {

    /**
     * 平台错误码
     * 0000：正常
     * 1000：认证失败
     * 1001：授权失败
     * 9001：参数校验失败
     * 9999：系统错误
     */
    private String errCode;

    /**
     * 平台错误信息
     * 0000：正常
     * 1000：认证失败
     * 1001：授权失败
     * 9001：参数校验失败
     * 9999：系统错误
     */
    private String errMsg;

    /**
     * 消息ID，原样返回
     */
    private String msgId;

    /**
     * 报文应答时间 格式yyyy-MM-dd HH:mm:ss
     */
    private String responseTimeStamp;

    /**
     * 请求系统预留字段
     */
    private String srcReserve;

    /**
     * 商户号，原样返回
     */
    private String mid;

    /**
     * 终端号，原样返回
     */
    private String tid;

    /**
     * 商户订单号
     */
    private String merOrderId;

    /**
     * 商户名称
     */
    private String merName;

    /**
     * 平台流水号
     */
    private String seqId;

    /**
     * 交易状态
     */
    private String status;

    /**
     * 支付渠道商户号
     */
    private String targetMid;

    /**
     * 目标平台单号 退货交易时不返回
     */
    private String targetOrderId;

    /**
     * 目标平台状态
     */
    private String targetStatus;

    /**
     * 目标平台代码
     */
    private String targetSys;

    /**
     * 支付总金额
     */
    private Long totalAmount;

    /**
     * 总退款金额
     */
    private String refundAmount;

    /**
     * 退款渠道列表
     */
    private String refundFunds;

    /**
     * 退款渠道描述
     */
    private String refundFundsDesc;

    /**
     * 实付部分退款金额
     */
    private Long refundInvoiceAmount;

    /**
     * 退货订单号
     */
    private String refundOrderId;

    /**
     * 目标系统退货订单号
     */
    private String refundTargetOrderId;

    /**
     * 营销联盟优惠金额 仅享受联盟优惠的订单，查询返回
     */
    private Long yxlmAmount;

    /**
     * 退款状态 详见取值说明
     */
    private String refundStatus;

    /**
     * 商户出资优惠金额 目前支持微信返回，其他渠道产品规划中
     */
    private Long refundMerchantContribute;

    /**
     * 其他出资优惠金额 目前支持微信返回，其他渠道产品规划中
     */
    private Long refundOtherContribute;


    public String getErrCode() {
        return errCode;
    }

    public void setErrCode(String errCode) {
        this.errCode = errCode;
    }

    public String getErrMsg() {
        return errMsg;
    }

    public void setErrMsg(String errMsg) {
        this.errMsg = errMsg;
    }

    public String getMsgId() {
        return msgId;
    }

    public void setMsgId(String msgId) {
        this.msgId = msgId;
    }

    public String getResponseTimeStamp() {
        return responseTimeStamp;
    }

    public void setResponseTimeStamp(String responseTimeStamp) {
        this.responseTimeStamp = responseTimeStamp;
    }

    public String getSrcReserve() {
        return srcReserve;
    }

    public void setSrcReserve(String srcReserve) {
        this.srcReserve = srcReserve;
    }

    public String getMid() {
        return mid;
    }

    public void setMid(String mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getMerOrderId() {
        return merOrderId;
    }

    public void setMerOrderId(String merOrderId) {
        this.merOrderId = merOrderId;
    }

    public String getMerName() {
        return merName;
    }

    public void setMerName(String merName) {
        this.merName = merName;
    }

    public String getSeqId() {
        return seqId;
    }

    public void setSeqId(String seqId) {
        this.seqId = seqId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getTargetMid() {
        return targetMid;
    }

    public void setTargetMid(String targetMid) {
        this.targetMid = targetMid;
    }

    public String getTargetOrderId() {
        return targetOrderId;
    }

    public void setTargetOrderId(String targetOrderId) {
        this.targetOrderId = targetOrderId;
    }

    public String getTargetStatus() {
        return targetStatus;
    }

    public void setTargetStatus(String targetStatus) {
        this.targetStatus = targetStatus;
    }

    public String getTargetSys() {
        return targetSys;
    }

    public void setTargetSys(String targetSys) {
        this.targetSys = targetSys;
    }

    public Long getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(Long totalAmount) {
        this.totalAmount = totalAmount;
    }

    public String getRefundAmount() {
        return refundAmount;
    }

    public void setRefundAmount(String refundAmount) {
        this.refundAmount = refundAmount;
    }

    public String getRefundFunds() {
        return refundFunds;
    }

    public void setRefundFunds(String refundFunds) {
        this.refundFunds = refundFunds;
    }

    public String getRefundFundsDesc() {
        return refundFundsDesc;
    }

    public void setRefundFundsDesc(String refundFundsDesc) {
        this.refundFundsDesc = refundFundsDesc;
    }

    public Long getRefundInvoiceAmount() {
        return refundInvoiceAmount;
    }

    public void setRefundInvoiceAmount(Long refundInvoiceAmount) {
        this.refundInvoiceAmount = refundInvoiceAmount;
    }

    public String getRefundOrderId() {
        return refundOrderId;
    }

    public void setRefundOrderId(String refundOrderId) {
        this.refundOrderId = refundOrderId;
    }

    public String getRefundTargetOrderId() {
        return refundTargetOrderId;
    }

    public void setRefundTargetOrderId(String refundTargetOrderId) {
        this.refundTargetOrderId = refundTargetOrderId;
    }

    public Long getYxlmAmount() {
        return yxlmAmount;
    }

    public void setYxlmAmount(Long yxlmAmount) {
        this.yxlmAmount = yxlmAmount;
    }

    public String getRefundStatus() {
        return refundStatus;
    }

    public void setRefundStatus(String refundStatus) {
        this.refundStatus = refundStatus;
    }

    public Long getRefundMerchantContribute() {
        return refundMerchantContribute;
    }

    public void setRefundMerchantContribute(Long refundMerchantContribute) {
        this.refundMerchantContribute = refundMerchantContribute;
    }

    public Long getRefundOtherContribute() {
        return refundOtherContribute;
    }

    public void setRefundOtherContribute(Long refundOtherContribute) {
        this.refundOtherContribute = refundOtherContribute;
    }
}
